@@ -1,12 +1,13 @@
-#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(feature = "doc_cfg", feature(doc_cfg))]
 #![deny(
     nonstandard_style,
     rust_2018_idioms,
     rustdoc::broken_intra_doc_links,
     rustdoc::private_intra_doc_links
 )]
-#![forbid(non_ascii_idents, unsafe_code)]
+#![forbid(unsafe_code)]
 #![warn(
+    non_ascii_idents,
     deprecated_in_future,
     missing_copy_implementations,
     missing_debug_implementations,
@@ -16,8 +17,12 @@
     unused_labels,
     unused_lifetimes,
     unused_qualifications,
-    unused_results
+    unused_results,
+    clippy::pedantic,
+    clippy::cargo,
+    unsafe_op_in_unsafe_fn
 )]
+#![allow(clippy::cargo_common_metadata, clippy::no_effect_underscore_binding)]
 
 /*!
 [`deadpool`] is a dead simple async pool for connections and objects of any type.
@@ -31,11 +36,15 @@ use fantoccini::{ClientBuilder, Locator};
 
 #[tokio::main]
 async fn main() {
-    # let webdriver_install_dir = dbg!(tempfile::Builder::new()
+    # let webdriver_install_dir = tempfile::Builder::new()
     #     .prefix("deadpool-fantoccini-test-webdriver-install-")
     #     .tempdir()
-    #     .unwrap());
+    #     .unwrap();
     # let webdriver_install_path = webdriver_install_dir.path().to_path_buf();
+    # defer_lite::defer! {
+    #    webdriver_install_dir.close().unwrap();
+    # };
+
     # let webdriver_path = tokio::task::spawn_blocking(move || {
     #     webdriver_install::Driver::Chrome
     #         .install_into(webdriver_install_path)
@@ -43,11 +52,15 @@ async fn main() {
     # })
     # .await
     # .unwrap();
-    # let mut webdriver = std::process::Command::new(webdriver_path)
+    #
+    # let mut webdriver = std::process::Command::new(&webdriver_path)
     #     .arg("--port=4444")
     #     .spawn()
     #     .unwrap();
-    # defer_lite::defer! { let _ = webdriver.kill(); };
+    # defer_lite::defer! {
+    #    webdriver.kill().unwrap();
+    #    webdriver.wait().unwrap();
+    # };
     #
     let manager = Manager::new("http://localhost:4444", ClientBuilder::native());
     let pool = Pool::builder(manager).max_size(5).build().unwrap();
@@ -72,11 +85,13 @@ async fn main() {
 
 use deadpool::async_trait;
 
-#[cfg(feature = "native-tls")]
+#[cfg(any(feature = "native-tls", feature = "doc_cfg"))]
+#[cfg_attr(feature = "doc_cfg", doc(cfg(feature = "native-tls")))]
 /// Type aliases for using this crate with [`native-tls`](https://crates.io/crates/native-tls).
 pub mod native_tls;
 
-#[cfg(feature = "rustls-tls")]
+#[cfg(any(feature = "rustls-tls", feature = "doc_cfg"))]
+#[cfg_attr(feature = "doc_cfg", doc(cfg(feature = "rustls-tls")))]
 /// Type aliases for using this crate with [`rustls`](https://crates.io/crates/rustls).
 pub mod rustls_tls;
 
